/*
 * An opener for a file provided via the filesystem client interface.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "client_file_accessor.h"
#include "client_file_opener.h"

/* Return a file identifier for the given 'path'. */

fileid_t ClientFileOpener::get_fileid(const char *path)
{
    _paths.insert(FilePathEntry(_counter, path));

    return _counter++;
}

/* Return a new accessor for 'fileid'. */

Accessor *ClientFileOpener::make_accessor(fileid_t fileid)
{
    FilePaths::iterator found = _paths.find(fileid);

    if (found != _paths.end())
        return new ClientFileAccessor(found->second, fileid);
    else
        return NULL;
}

// vim: tabstop=4 expandtab shiftwidth=4
